// importing necessary modules I used for this graph.
import { getCsv } from './getCsv';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Select SVG html element
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

const render = (data,total) => {
  // Defining pie chart data
  const pieData = pie().value(d=>d['Net worth in Billion (USD)'])(data);
  
  // Defining different colors for pie chart
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "red",
      "green",
      "black",
      "blue",
      "pink",
      "maroon",
      "gray",
      "orange",
      "navy",
      "purple"
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data['Net worth in Billion (USD)']));
  
  // Defining legends for the pie chart
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data['Net worth in Billion (USD)']));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data['Net worth in Billion (USD)']/1000))+"K");
}

const run = async () => {
  let data = await getCsv()
  let total = 0
  data.forEach(d=>{
    d['Net worth in Billion (USD)'] = +d['Net worth in Billion (USD)'];
    total += d['Net worth in Billion (USD)']
  });
  console.log(data)
  
  // Rendering data
	render(data,total);
};
run();